==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/mots/lang/mots_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grupo importante:</b>é moi aconsellable seleccionar unha palabra chave neste grupo.',
	'avis_doublon_mot_cle' => 'Xa existe unha palabra con ese título. Está seguro de que quere crear o mesmo?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'o equipo de xestión do web',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'o equipo de redacción',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitantes do web público cando escriben unha mensaxe nun foro.',

	// C
	'creer_et_associer_un_mot' => 'Créér et associer un mot-clé', # MODIF

	// I
	'icone_creation_groupe_mots' => 'Crear un novo grupo de palabras',
	'icone_creation_mots_cles' => 'Crear unha nova palabra chave',
	'icone_modif_groupe_mots' => 'Modificar este grupo de palabras',
	'icone_modifier_mot' => 'Modificar esta palabra clave',
	'icone_mots_cles' => 'Palabras-clave',
	'icone_supprimer_groupe_mots' => 'Borrar este grupo',
	'icone_voir_groupe_mots' => 'Voir ce groupe de mots', # NEW
	'icone_voir_tous_mots_cles' => 'Ver todas as palabras chave',
	'info_1_groupe_mots' => '1 groupe de mots', # NEW
	'info_articles_lies_mot' => 'Os artigos ligados a esta palabra chave',
	'info_aucun_groupe_mots' => 'Aucun groupe de mots', # NEW
	'info_aucun_mot_cle' => 'Ningunha palabra-clave',
	'info_changer_nom_groupe' => 'Trocar o nome deste grupo:',
	'info_creation_mots_cles' => 'Crea e configura aquí as palabras chave do web',
	'info_dans_groupe' => 'No grupo:',
	'info_delet_mots_cles' => 'Solicitouse eliminar a palabra clave
<b>@titre_mot@</b> (@type_mot@). Esta palabra clave est&aacute; ligada a
<b>@texte_lie@</b>, ten que confirmar a s&uacute;a decisi&oacute;n :', # MODIF
	'info_groupe_important' => 'Grupo importante',
	'info_modifier_mot' => 'Modificar a palabra clave :',
	'info_mots_cles' => 'As palabras chave',
	'info_mots_cles_association' => 'As palabras chave deste grupo poden estar aociadas:',
	'info_nb_groupe_mots' => '@nb@ groupes de mots', # NEW
	'info_oui_suppression_mot_cle' => 'Quero suprimir definitivamente esta palabra chave.',
	'info_question_mots_cles' => 'Quere empregar as palabras chave neste seu web?',
	'info_qui_attribue_mot_cle' => 'As palabras deste grupo poden ser atribuidas a:',
	'info_remplacer_mot' => 'Substituír "@titre@"',
	'info_retirer_mot' => 'Retirar esta palabra',
	'info_retirer_mots' => 'Retirar todas as palabras',
	'info_rubriques_liees_mot' => 'Os temas ligados a esta palabra chave',
	'info_selection_un_seul_mot_cle' => 'Neste grupo pódese seleccionar <b>só unha palabra chave</b> ao mesmo tempo.', # MODIF
	'info_supprimer_mot' => 'suprimir esta palabra',
	'info_titre_mot_cle' => 'Nome ou título da palabra chave',
	'info_un_mot' => 'Unha palabra a cada vez',
	'item_ajout_mots_cles' => 'Permitir palabras chave nos foros',
	'item_non_ajout_mots_cles' => 'Prohibir o uso de palabras chave nos foros',
	'item_non_utiliser_config_groupe_mots_cles' => 'Non usar a configuración avanzada dos grupos de palabras chave',
	'item_non_utiliser_mots_cles' => 'Non usar as palabras chave',
	'item_utiliser_config_groupe_mots_cles' => 'Empregar a configuración avanzada dos grupos de palabras chave',
	'item_utiliser_mots_cles' => 'Empregar as palabras chave',

	// L
	'lien_ajouter_mot' => 'Engadir a palabra-clave',
	'logo_groupe' => 'LOGO DESTE GRUPO',
	'logo_mot_cle' => 'LOGO DA PALABRA CHAVE',

	// T
	'texte_config_groupe_mots_cles' => 'Quere activar a configuraci&oacute;n avanzada das palabras clave,
  para indicar, por exemplo que se pode seleccionar unha palabra &uacute;nica
  por grupo, que un grupo &eacute; importante... ?', # MODIF
	'texte_mots_cles' => 'As palabras chave permiten crear ligazóns temáticas entre os artigos
  sen depender do seu emprazamento dentro dos temas. Pódese, dende
  mellorar a navegación do seu web, ata empregar as súas propiedades
  para personalizar a presentación dos artigos dentro dos seus esqueletos.',
	'texte_mots_cles_dans_forum' => 'Quere permitir o emprego de palabras chave, seleccionables polos visitantes, nos foros do web público? (Atención: esta opción é relativamente complexa de empregar correctamente.)',
	'texte_nouveau_mot' => 'Nova palabra',
	'titre_config_groupe_mots_cles' => 'Configuración dos grupos de palabras chave',
	'titre_gauche_mots_edit' => 'PALABRA NÚMERO:',
	'titre_groupe_mots' => 'Groupe de mots-clés', # NEW
	'titre_groupe_mots_numero' => 'GROUPE DE MOTS NUMÉRO :', # NEW
	'titre_groupes_mots' => 'Groupes de mots-clés', # NEW
	'titre_mots_cles_dans_forum' => 'Palabras chave nos foros do web público',
	'titre_mots_tous' => 'As palabras chave',
	'titre_nouveau_groupe' => 'Novo grupo',
	'titre_objets_lies_mot' => 'Liés à ce mot-clé :', # NEW
	'titre_page_mots_tous' => 'Palabras chave'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/mots/lang/mots_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Grupo importante:</b>é moi aconsellable seleccionar unha palabra chave neste grupo.',
	'avis_doublon_mot_cle' => 'Xa existe unha palabra con ese título. Está seguro de que quere crear o mesmo?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'o equipo de xestión do web',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'o equipo de redacción',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitantes do web público cando escriben unha mensaxe nun foro.',

	// C
	'creer_et_associer_un_mot' => 'Créér et associer un mot-clé', # MODIF

	// I
	'icone_creation_groupe_mots' => 'Crear un novo grupo de palabras',
	'icone_creation_mots_cles' => 'Crear unha nova palabra chave',
	'icone_modif_groupe_mots' => 'Modificar este grupo de palabras',
	'icone_modifier_mot' => 'Modificar esta palabra clave',
	'icone_mots_cles' => 'Palabras-clave',
	'icone_supprimer_groupe_mots' => 'Borrar este grupo',
	'icone_voir_groupe_mots' => 'Voir ce groupe de mots', # NEW
	'icone_voir_tous_mots_cles' => 'Ver todas as palabras chave',
	'info_1_groupe_mots' => '1 groupe de mots', # NEW
	'info_articles_lies_mot' => 'Os artigos ligados a esta palabra chave',
	'info_aucun_groupe_mots' => 'Aucun groupe de mots', # NEW
	'info_aucun_mot_cle' => 'Ningunha palabra-clave',
	'info_changer_nom_groupe' => 'Trocar o nome deste grupo:',
	'info_creation_mots_cles' => 'Crea e configura aquí as palabras chave do web',
	'info_dans_groupe' => 'No grupo:',
	'info_delet_mots_cles' => 'Solicitouse eliminar a palabra clave
<b>@titre_mot@</b> (@type_mot@). Esta palabra clave est&aacute; ligada a
<b>@texte_lie@</b>, ten que confirmar a s&uacute;a decisi&oacute;n :', # MODIF
	'info_groupe_important' => 'Grupo importante',
	'info_modifier_mot' => 'Modificar a palabra clave :',
	'info_mots_cles' => 'As palabras chave',
	'info_mots_cles_association' => 'As palabras chave deste grupo poden estar aociadas:',
	'info_nb_groupe_mots' => '@nb@ groupes de mots', # NEW
	'info_oui_suppression_mot_cle' => 'Quero suprimir definitivamente esta palabra chave.',
	'info_question_mots_cles' => 'Quere empregar as palabras chave neste seu web?',
	'info_qui_attribue_mot_cle' => 'As palabras deste grupo poden ser atribuidas a:',
	'info_remplacer_mot' => 'Substituír "@titre@"',
	'info_retirer_mot' => 'Retirar esta palabra',
	'info_retirer_mots' => 'Retirar todas as palabras',
	'info_rubriques_liees_mot' => 'Os temas ligados a esta palabra chave',
	'info_selection_un_seul_mot_cle' => 'Neste grupo pódese seleccionar <b>só unha palabra chave</b> ao mesmo tempo.', # MODIF
	'info_supprimer_mot' => 'suprimir esta palabra',
	'info_titre_mot_cle' => 'Nome ou título da palabra chave',
	'info_un_mot' => 'Unha palabra a cada vez',
	'item_ajout_mots_cles' => 'Permitir palabras chave nos foros',
	'item_non_ajout_mots_cles' => 'Prohibir o uso de palabras chave nos foros',
	'item_non_utiliser_config_groupe_mots_cles' => 'Non usar a configuración avanzada dos grupos de palabras chave',
	'item_non_utiliser_mots_cles' => 'Non usar as palabras chave',
	'item_utiliser_config_groupe_mots_cles' => 'Empregar a configuración avanzada dos grupos de palabras chave',
	'item_utiliser_mots_cles' => 'Empregar as palabras chave',

	// L
	'lien_ajouter_mot' => 'Engadir a palabra-clave',
	'logo_groupe' => 'LOGO DESTE GRUPO',
	'logo_mot_cle' => 'LOGO DA PALABRA CHAVE',

	// T
	'texte_config_groupe_mots_cles' => 'Quere activar a configuraci&oacute;n avanzada das palabras clave,
  para indicar, por exemplo que se pode seleccionar unha palabra &uacute;nica
  por grupo, que un grupo &eacute; importante... ?', # MODIF
	'texte_mots_cles' => 'As palabras chave permiten crear ligazóns temáticas entre os artigos
  sen depender do seu emprazamento dentro dos temas. Pódese, dende
  mellorar a navegación do seu web, ata empregar as súas propiedades
  para personalizar a presentación dos artigos dentro dos seus esqueletos.',
	'texte_mots_cles_dans_forum' => 'Quere permitir o emprego de palabras chave, seleccionables polos visitantes, nos foros do web público? (Atención: esta opción é relativamente complexa de empregar correctamente.)',
	'texte_nouveau_mot' => 'Nova palabra',
	'titre_config_groupe_mots_cles' => 'Configuración dos grupos de palabras chave',
	'titre_gauche_mots_edit' => 'PALABRA NÚMERO:',
	'titre_groupe_mots' => 'Groupe de mots-clés', # NEW
	'titre_groupe_mots_numero' => 'GROUPE DE MOTS NUMÉRO :', # NEW
	'titre_groupes_mots' => 'Groupes de mots-clés', # NEW
	'titre_mots_cles_dans_forum' => 'Palabras chave nos foros do web público',
	'titre_mots_tous' => 'As palabras chave',
	'titre_nouveau_groupe' => 'Novo grupo',
	'titre_objets_lies_mot' => 'Liés à ce mot-clé :', # NEW
	'titre_page_mots_tous' => 'Palabras chave'
);

?>
